<?php
/*
 * All Front-End Helper Functions
 * Author & Copyright: VictorThemes
 * URL: https://victorthemes.com
 */

/* Exclude category from blog */
if( ! function_exists( 'riffel_vt_excludeCat' ) ) {
  function riffel_vt_excludeCat($query) {
  	if ( $query->is_home ) {
  		$exclude_cat_ids = cs_get_option('theme_exclude_categories');
  		if($exclude_cat_ids) {
  			foreach( $exclude_cat_ids as $exclude_cat_id ) {
  				$exclude_from_blog[] = '-'. $exclude_cat_id;
  			}
  			$query->set('cat', implode(',', $exclude_from_blog));
  		}
  	}
  	return $query;
  }
  add_filter('pre_get_posts', 'riffel_vt_excludeCat');
}

/* Excerpt Length */
class RiffelExcerpt {

  // Default length (by WordPress)
  public static $length = 55;

  // Output: riffel_excerpt('short');
  public static $types = array(
    'short' => 25,
    'regular' => 55,
    'long' => 100
  );

  /**
   * Sets the length for the excerpt,
   * then it adds the WP filter
   * And automatically calls the_excerpt();
   *
   * @param string $new_length
   * @return void
   * @author Baylor Rae'
   */
  public static function length($new_length = 55) {
    RiffelExcerpt::$length = $new_length;
    add_filter('excerpt_length', 'RiffelExcerpt::new_length');
    RiffelExcerpt::output();
  }

  // Tells WP the new length
  public static function new_length() {
    if( isset(RiffelExcerpt::$types[RiffelExcerpt::$length]) )
      return RiffelExcerpt::$types[RiffelExcerpt::$length];
    else
      return RiffelExcerpt::$length;
  }

  // Echoes out the excerpt
  public static function output() {
    the_excerpt();
  }

}

// Custom Excerpt Length
if( ! function_exists( 'riffel_excerpt' ) ) {
  function riffel_excerpt($length = 55) {
    RiffelExcerpt::length($length);
  }
}

if ( ! function_exists( 'riffel_new_excerpt_more' ) ) {
  function riffel_new_excerpt_more( $more ) {
    return ' [...]';
  }
  add_filter('excerpt_more', 'riffel_new_excerpt_more');
}

/* Tag Cloud Widget - Remove Inline Font Size */
if( ! function_exists( 'riffel_vt_tag_cloud' ) ) {
  function riffel_vt_tag_cloud($tag_string){
    return preg_replace("/style='font-size:.+pt;'/", '', $tag_string);
  }
  add_filter('wp_generate_tag_cloud', 'riffel_vt_tag_cloud', 10, 3);
}

// / Tag Cloud Widget - Remove Inline Font Size /
add_filter( 'widget_tag_cloud_args', 'riffel_change_tag_cloud_font_sizes');

/**
 * Change the Tag Cloud's Font Sizes.
 *
 * @since 1.0.0
 *
 * @param array $args
 *
 * @return array
 */
function riffel_change_tag_cloud_font_sizes( array $args ) {
  $args['smallest'] = '11';
  $args['largest'] = '11';

  return $args;
}



/* Password Form */
if( ! function_exists( 'riffel_vt_password_form' ) ) {
  function riffel_vt_password_form( $output ) {
    $output = str_replace( 'type="submit"', 'type="submit" class=""', $output );
    return $output;
  }
  add_filter('the_password_form' , 'riffel_vt_password_form');
}

/* Maintenance Mode */
if( ! function_exists( 'riffel_vt_maintenance_mode' ) ) {
  function riffel_vt_maintenance_mode(){

    $maintenance_mode_page = cs_get_option( 'maintenance_mode_page' );

    if ( ! empty( $maintenance_mode_page ) && ! is_user_logged_in() ) {
      get_template_part('layouts/post/content', 'maintenance');
      exit;
    }

  }
  add_action( 'wp', 'riffel_vt_maintenance_mode', 1 );
}

/* Widget Layouts */
if ( ! function_exists( 'riffel_vt_footer_widgets' ) ) {
  function riffel_vt_footer_widgets() {

    $output = '';
    $footer_widget_layout = cs_get_option('footer_widget_layout');

    if( $footer_widget_layout ) {

      switch ( $footer_widget_layout ) {
        case 1: $widget = array('piece' => 1, 'class' => 'col-md-12'); break;
        case 2: $widget = array('piece' => 2, 'class' => 'col-md-6'); break;
        case 3: $widget = array('piece' => 3, 'class' => 'col-md-4'); break;
        case 4: $widget = array('piece' => 4, 'class' => 'col-md-3 col-sm-6'); break;
        case 5: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 6: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 2); break;
        case 7: $widget = array('piece' => 3, 'class' => 'col-md-3', 'layout' => 'col-md-6', 'queue' => 3); break;
        case 8: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 1); break;
        case 9: $widget = array('piece' => 4, 'class' => 'col-md-2', 'layout' => 'col-md-6', 'queue' => 4); break;
        default : $widget = array('piece' => 4, 'class' => 'col-md-3'); break;
      }

      for( $i = 1; $i < $widget["piece"]+1; $i++ ) {

        $widget_class = ( isset( $widget["queue"] ) && $widget["queue"] == $i ) ? $widget["layout"] : $widget["class"];

        $output .= '<div class="'. esc_attr( $widget_class).'">';
        ob_start();
        if (is_active_sidebar('footer-'. $i)) {
          dynamic_sidebar( 'footer-'. $i );
        }
        $output .= ob_get_clean();
        $output .= '</div>';

      }
    }

    return $output;

  }
}

/* WP Link Pages */
if ( ! function_exists( 'riffel_wp_link_pages' ) ) {
  function riffel_wp_link_pages() {
    $defaults = array(
      'before'           => '<div class="wp-link-pages">' . esc_html__( 'Pages:', 'riffel' ),
      'after'            => '</div>',
      'link_before'      => '<span>',
      'link_after'       => '</span>',
      'next_or_number'   => 'number',
      'separator'        => ' ',
      'pagelink'         => '%',
      'echo'             => 1
    );
    wp_link_pages( $defaults );
  }
}

/* Metas */
if ( ! function_exists( 'riffel_post_metas' ) ) {
  function riffel_post_metas() {
  $metas_hide = (array) cs_get_option( 'theme_metas_hide' );
  global $post;
  ?>
  <h5 class="blog-meta">
    <?php
    if ( !in_array( 'category', $metas_hide ) ) { // Category Hide
      if ( get_post_type() === 'post') {
        $category_list = get_the_category_list( ', ', '', $post->ID );
        if ( $category_list ) {
          echo '<span class="meta-item">'. $category_list .' </span>';
        }
      }
    } // Category Hides
    if ( !in_array( 'date', $metas_hide ) ) { // Date Hide
    ?>
    <span class="meta-item">
      <span><?php echo get_the_date(); ?></span>
    </span>
    <?php } // Date Hides
    if ( !in_array( 'author', $metas_hide ) ) { // Author Hide
    ?>
    <span class="meta-item">
      <?php
      printf(
        ''. esc_html__('by','riffel') .' <a href="%1$s" rel="author">%2$s</a>',
        esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
        get_the_author()
      );
      ?>
    </span>
    <?php } ?>
  </h5>
  <?php
  }
}

// information portfolio
if ( ! function_exists( 'riffel_portfolio_information_meta' ) ) {
function riffel_portfolio_information_meta( $meta_name, $meta_id ) {
    global $post;
    $portfolio_meta  = get_post_meta( $post->ID, $meta_name, true );
    $informations = $portfolio_meta[$meta_id];
    if ($informations) {
      $infos = $informations;
    } else {
      $infos = array();
    } ?>
      <ul>
        <?php
        foreach ( $infos as $key => $information ) {
          $meta_info = explode('<br>', nl2br($information['meta_info'], false));
          $meta_url = explode('<br>', nl2br($information['info_url'], false));

          if(!empty($information['info_url'])) {
            $meta_i = count($meta_info);
            $meta_u = count($meta_url);
            if ($meta_i > $meta_u) {
              $meta_info = array_slice($meta_info, 0, count($meta_url));
            } elseif($meta_u > $meta_i) {
              $meta_url = array_slice($meta_url, 0, count($meta_info));
            } else {
              $meta_info = $meta_info;
              $meta_url = $meta_url;
            }
            $totlal_info = array_combine($meta_info, $meta_url);
            ?>
              <li>
                <span class="info-list-title"><?php echo esc_attr($information['title']); ?></span>
                <dd>
                <span class="info-list-subtitle">
                  <?php foreach ($totlal_info as $info => $url) {  ?>
                    <a href="<?php echo trim($url);?>"><?php echo trim($info); ?></a>
                  <?php } ?>
                </span>
                </dd>
              </li>
          <?php
          } else {
               ?>
              <li>
                <span class="info-list-title"><?php echo esc_attr($information['title']); ?></span>
                <dd>
                <span class="info-list-subtitle">
                <?php foreach ($meta_info as $key => $info) { ?>
                  <?php echo trim($info); ?>
                <?php } ?>
                </span>
                </dd>
              </li>
              <?php
          }
        } ?>
      </ul>
<?php
}
}

// Banner information list
if ( ! function_exists( 'riffel_portfolio_banner_information_meta' ) ) {
function riffel_portfolio_banner_information_meta( $meta_name, $meta_id ) {
    global $post;
    $portfolio_meta  = get_post_meta( $post->ID, $meta_name, true );
    $informations = $portfolio_meta[$meta_id];
    if ($informations) {
      $infos = $informations;
    } else {
      $infos = array();
    } ?>
    <ul>
    <?php
    foreach ( $infos as $key => $information ) {
      $banner_meta_txt = explode('<br>', nl2br($information['banner_meta_txt'], false));
      $banner_meta_url = explode('<br>', nl2br($information['banner_meta_url'], false));

      if(!empty($information['banner_meta_url'])) {
        $meta_i = count($banner_meta_txt);
        $meta_u = count($banner_meta_url);
        if ($meta_i > $meta_u) {
          $banner_meta_txt = array_slice($banner_meta_txt, 0, count($banner_meta_url));
        } elseif($meta_u > $meta_i) {
          $banner_meta_url = array_slice($banner_meta_url, 0, count($banner_meta_txt));
        } else {
          $banner_meta_txt = $banner_meta_txt;
          $banner_meta_url = $banner_meta_url;
        }
        $totlal_info = array_combine($banner_meta_txt, $banner_meta_url);
        ?>
          <li>
            <span class="info-list-title"><?php echo esc_attr($information['banner_info_title']); ?></span>
            <span class="info-list-subtitle">
        <?php foreach ($totlal_info as $info => $url) {  ?>
                  <span class="portfolio-category-item"><a href="<?php echo trim($url);?>"><?php echo trim($info); ?></a></span>
          <?php } ?>
            </span>
          </li>
      <?php
      } else {
           ?>
          <li>
            <span class="info-list-title"><?php echo esc_attr($information['banner_info_title']); ?></span>
            <span class="info-list-subtitle">
        <?php foreach ($banner_meta_txt as $key => $info) { ?>
                  <span><?php echo trim($info); ?></span>
          <?php } ?>
            </span>
          </li>
          <?php
      }
    } ?>
    </ul>
<?php }
}

// single pagination portfolio
if ( ! function_exists( 'riffel_portfolio_next_prev' ) ) {
function riffel_portfolio_next_prev() {
  global $post;
    $p_home_url = cs_get_option('portfolio_home_url');
    $next_port = cs_get_option('next_port');
    $prev_port = cs_get_option('prev_port');
    $previous_project = $prev_port ? $prev_port : esc_html__( 'Previous Project', 'riffel' );
    $next_project = $next_port ? $next_port : esc_html__( 'Next Project', 'riffel' );
    ?>
    <div class="rifl-more-posts posts-style-two">
    <div class="row">
      <div class="col-md-4">
        <?php $prev_post = get_adjacent_post(false, '', true);
        if(!empty($prev_post)) {
          $riffel_large_image =  wp_get_attachment_image_src( get_post_thumbnail_id($prev_post->ID), 'fullsize', false, '' );
          $riffel_large_image = isset($riffel_large_image[0]) ? $riffel_large_image[0] : '';
            echo '<a href="' . esc_url(get_permalink($prev_post->ID)) . '" class="more-posts-link"><span class="more-post-type">'.esc_attr($previous_project).'</span><span class="more-post-title">' . esc_attr($prev_post->post_title) . '</span>';
          if ($riffel_large_image) {
            echo '<span class="rifl-image" style="background-image: url('.esc_url($riffel_large_image).');"></span>';
          }
            echo '</a>';
        } ?>

        </a>
      </div>
      <div class="col-md-4 text-center">
        <a href="<?php echo esc_url( $p_home_url ); ?>" class="post-grid-view"><span class="grid-icon"></span> <span class="grid-icon"></span></a>
      </div>
      <div class="col-md-4 text-right">
        <?php $next_post = get_adjacent_post(false, '', false);
        if(!empty($next_post)) {
          $riffel_large_image =  wp_get_attachment_image_src( get_post_thumbnail_id($next_post->ID), 'fullsize', false, '' );
          $riffel_large_image = isset($riffel_large_image[0]) ? $riffel_large_image[0] : '';
            echo '<a href="' . esc_url(get_permalink($next_post->ID)) . '" class="more-posts-link"><span class="more-post-type">'.esc_attr($next_project).'</span><span class="more-post-title">'. esc_attr($next_post->post_title) .'</span>';
          if ($riffel_large_image) {
            echo '<span class="rifl-image" style="background-image: url('.esc_url($riffel_large_image).');"></span>';
          }
            echo '</a>';
        } ?>
        </a>
      </div>
    </div>
  </div>
<?php
}
}

/* Author Info */
if ( ! function_exists( 'riffel_author_info' ) ) {
  function riffel_author_info() {

    if (get_the_author_meta( 'url' )) {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_the_author_meta( 'url' );
      $target = 'target="_blank"';
    } else {
      $author_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $website_url = get_author_posts_url( get_the_author_meta( 'ID' ) );
      $target = '';
    }

    // variables
    $author_text = cs_get_option('author_text');
    $author_text = $author_text ? $author_text : esc_html__( 'Author', 'riffel' );
    $author_content = get_the_author_meta( 'description' );
if ($author_content) {
?>
  <div class="rifl-author-info">
    <div class="author-avatar">
      <a href="<?php echo esc_url($website_url); ?>" <?php echo esc_attr($target); ?>>
        <?php echo get_avatar( get_the_author_meta( 'ID' ), 80 ); ?>
      </a>
    </div>
    <div class="author-content">
      <div class="author-pro"><?php echo esc_attr($author_text); ?></div>
      <a href="<?php echo esc_url($author_url); ?>" class="author-name"><?php echo esc_attr(get_the_author_meta('first_name')).' '.get_the_author_meta('last_name'); ?></a>
      <p><?php echo esc_attr(get_the_author_meta( 'description' )); ?></p>
      <!--post author socail start\-->
        <?php
        $facebook = get_the_author_meta('facebook');
        $twitter  = get_the_author_meta('twitter');
        $linkedin = get_the_author_meta('linkedin');
        $instagram = get_the_author_meta('instagram');
        ?>
        <div class="rifl-socials">
          <?php
          if(!empty($facebook)) {
          echo '<a href="'.esc_url($facebook).'" target="_blank"><i class="fa fa-facebook"></i></a>';
          }
           if(!empty($twitter)) {
          echo '<a href="'.esc_url($twitter).'" target="_blank"><i class="fa fa-twitter"></i></a>';
          }
          if(!empty($linkedin)) {
          echo '<a href="'.esc_url($linkedin).'" target="_blank"><i class="fa fa-linkedin"></i></a>';
          }
          if(!empty($instagram)) {
          echo '<a href="'.esc_url($instagram).'" target="_blank"><i class="fa fa-instagram"></i></a>';
          }
         ?>
    </div>
  </div>
</div>

<?php
} // if $author_content
  }
}

/* Pre Loader */
if ( ! function_exists( 'riffel_pre_loader' ) ) {
  function riffel_pre_loader() {
    $rifl_pre_loader = cs_get_option('pre_loader');
    $rifl_loader_style = cs_get_option('pre_loader_option');

    if ($rifl_pre_loader) {
      if($rifl_loader_style){
        $rifl_loader_class = $rifl_loader_style;
      } else{
        $rifl_loader_class = '';
      }
      if ($rifl_pre_loader) { ?>
        <div class="rifl-preloader">
          <div class="loader-wrap">
            <div class="loader">
              <div class="loader-inner <?php echo esc_attr($rifl_loader_class); ?>"></div>
            </div>
          </div>
        </div>
      <?php }
    }
  }
}

/* ==============================================
   Custom Comment Area Modification
=============================================== */
if ( ! function_exists( 'riffel_comment_modification' ) ) {
  function riffel_comment_modification($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    extract($args, EXTR_SKIP);
    if ( 'div' == $args['style'] ) {
      $tag = 'div';
      $add_below = 'comment';
    } else {
      $tag = 'li';
      $add_below = 'div-comment';
    }
    $comment_class = empty( $args['has_children'] ) ? '' : 'parent';
  ?>

  <<?php echo esc_attr($tag); ?> <?php comment_class('item ' . $comment_class .' ' ); ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-body">
    <?php endif; ?>
    <div class="comment-theme">
      <div class="comment-image">
        <?php if ( $args['avatar_size'] != 0 ) {
          echo get_avatar( $comment, 80 );
        } ?>
      </div>
    </div>
    <div class="comment-main-area">
      <div class="rifl-comments-meta">
        <h4><?php printf( '%s', get_comment_author() ); ?></h4>
        <span class="comments-date">
          <?php echo get_comment_date(); echo esc_html__( ' - ', 'riffel' ); ?>
          <span class="caps"><?php echo get_comment_time(); ?></span>
        </span>
      </div>

      <?php if ( $comment->comment_approved == '0' ) : ?>
      <em class="comment-awaiting-moderation"><?php echo esc_html__( 'Your comment is awaiting moderation.', 'riffel' ); ?></em>
      <?php endif; ?>
      <div class="comment-area">
        <?php comment_text(); ?>
      </div>
      <div class="reply">
        <?php
          comment_reply_link( array_merge( $args, array(
          'reply_text' => '<span class="comment-reply-link">'. esc_html__('Reply','riffel') .'</span>',
          'before' => '',
          'class'  => '',
          'depth' => $depth,
          'max_depth' => $args['max_depth']
          ) ) );
        ?>
        </div>
    </div>
  <?php if ( 'div' != $args['style'] ) : ?>
  </div>
  <?php endif;
  }
}

/* Title Area */
if ( ! function_exists( 'riffel_title_area' ) ) {
  function riffel_title_area() {

    global $post, $wp_query;

    // Get post meta in all type of WP pages
    $riffel_id    = ( isset( $post ) ) ? $post->ID : 0;
    $riffel_id    = ( is_home() ) ? get_option( 'page_for_posts' ) : $riffel_id;
    $riffel_id    = ( is_woocommerce_shop() ) ? wc_get_page_id( 'shop' ) : $riffel_id;
    $riffel_meta  = get_post_meta( $riffel_id, 'page_type_metabox', true );
    if ($riffel_meta && (!is_archive() || is_woocommerce_shop())) {
      $custom_title = $riffel_meta['page_custom_title'];
      if ($custom_title) {
        $custom_title = $custom_title;
      } elseif(post_type_archive_title()) {
        esc_attr(post_type_archive_title());
      } else {
        $custom_title = '';
      }
    } else { $custom_title = ''; }

    /**
     * For strings with necessary HTML, use the following:
     * Note that I'm only including the actual allowed HTML for this specific string.
     * More info: https://codex.wordpress.org/Function_Reference/wp_kses
     */
    $allowed_title_area_tags = array(
        'a' => array(
          'href' => array(),
        ),
        'span' => array(
          'class' => array(),
        )
    );

    if( $custom_title ) {
      echo esc_attr($custom_title);
    } elseif ( is_home() ) {
      bloginfo('name');
    } elseif ( is_search() ) {
      printf( esc_html__( 'Search Results for %s', 'riffel' ), '<span>' . get_search_query() . '</span>' );
    } elseif ( is_category() || is_tax() ){
      single_cat_title();
    } elseif ( is_tag() ){
      single_tag_title(esc_html__('Posts Tagged: ', 'riffel'));
    } elseif ( is_archive() ){
      if ( is_day() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'riffel' ), $allowed_title_area_tags ), get_the_date());
      } elseif ( is_month() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'riffel' ), $allowed_title_area_tags ), get_the_date( 'F, Y' ));
      } elseif ( is_year() ) {
        printf( wp_kses( __( 'Archive for <span>%s</span>', 'riffel' ), $allowed_title_area_tags ), get_the_date( 'Y' ));
      } elseif ( is_author() ) {
        printf( wp_kses( __( 'Posts by: <span>%s</span>', 'riffel' ), $allowed_title_area_tags ), get_the_author_meta( 'display_name', $wp_query->post->post_author ));
      } elseif( is_woocommerce_shop() ) {
        echo esc_attr($custom_title);
      } elseif ( is_post_type_archive() ) {
        post_type_archive_title();
      } else {
        esc_html_e( 'Archives', 'riffel' );
      }
    } elseif( is_404() ) {
      esc_html_e('404', 'riffel');
    } else {
      esc_attr(the_title());
    }

  }
}

if ( ! function_exists( 'riffel_paging_nav' ) ) {
  function riffel_paging_nav($nav_query = NULL) {
    if ( function_exists('wp_pagenavi')) {
      echo '<div class="rifl-pagenavi">';
        wp_pagenavi();
      echo '</div>';
    } else {
      $older_post = cs_get_option('older_post');
      $newer_post = cs_get_option('newer_post');
      $older_post = $older_post ? $older_post : esc_html__( 'Previous', 'riffel' );
      $newer_post = $newer_post ? $newer_post : esc_html__( 'Next', 'riffel' );
      global $wp_query;
      $big = 999999999;
      $current = max( 1, get_query_var('paged') );
      $total = ($nav_query != NULL) ? $nav_query->max_num_pages : $wp_query->max_num_pages;

      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
      echo '<div class="rifl-pagenavi">';
      echo paginate_links( array(
        'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
        'format' => '?paged=%#%',
        'prev_text' => '<i class="fa fa-angle-left"></i> ' . $older_post,
        'next_text' => $newer_post . ' <i class="fa fa-angle-right"></i>',
        'current' => $current,
        'total' => $total,
        'type' => 'plain'
      ));
      echo '</div>';
      if($wp_query->max_num_pages == '1' ) {} else {echo '';}
    }
  }
}

/* Added next class to wp-pagenavi*/
add_filter('wp_pagenavi_class_nextpostslink', 'theme_pagination_nextpostslink_class');
function theme_pagination_nextpostslink_class($class_name) {
  return 'next';
}
